Documentation
¶
Overview ¶
Package v1 is the v1 version of the API.
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( // SchemeBuilder initializes a scheme builder SchemeBuilder = runtime.NewSchemeBuilder(addKnownTypes) // AddToScheme is a global function that registers this API group & version to a scheme AddToScheme = SchemeBuilder.AddToScheme )
var SchemeGroupVersion = schema.GroupVersion{Group: "auth.casbin.org", Version: "v1"}
SchemeGroupVersion is group version used to register these objects
Functions ¶
func Resource ¶
func Resource(resource string) schema.GroupResource
Resource takes an unqualified resource and returns a Group qualified GroupResource
Types ¶
type CasbinModel ¶
type CasbinModel struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec CasbinModelSpec `json:"spec,omitempty"`
Status CasbinModelStatus `json:"status,omitempty"`
}
CasbinModel is the Schema for the casbinmodels API
func (*CasbinModel) DeepCopy ¶
func (in *CasbinModel) DeepCopy() *CasbinModel
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CasbinModel.
func (*CasbinModel) DeepCopyInto ¶
func (in *CasbinModel) DeepCopyInto(out *CasbinModel)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*CasbinModel) DeepCopyObject ¶
func (in *CasbinModel) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type CasbinModelList ¶
type CasbinModelList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []CasbinModel `json:"items"`
}
CasbinModelList contains a list of CasbinModel
func (*CasbinModelList) DeepCopy ¶
func (in *CasbinModelList) DeepCopy() *CasbinModelList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CasbinModelList.
func (*CasbinModelList) DeepCopyInto ¶
func (in *CasbinModelList) DeepCopyInto(out *CasbinModelList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*CasbinModelList) DeepCopyObject ¶
func (in *CasbinModelList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type CasbinModelSpec ¶
type CasbinModelSpec struct {
//ModelText contains the content of casbin model
ModelText string `json:"modelText,omitempty"`
// This Model is valid only if enabled is true
Enabled bool `json:"enabled"`
}
CasbinModelSpec defines the desired state of CasbinModel
func (*CasbinModelSpec) DeepCopy ¶
func (in *CasbinModelSpec) DeepCopy() *CasbinModelSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CasbinModelSpec.
func (*CasbinModelSpec) DeepCopyInto ¶
func (in *CasbinModelSpec) DeepCopyInto(out *CasbinModelSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type CasbinModelStatus ¶
type CasbinModelStatus struct {
}
CasbinModelStatus defines the observed state of CasbinModel
func (*CasbinModelStatus) DeepCopy ¶
func (in *CasbinModelStatus) DeepCopy() *CasbinModelStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CasbinModelStatus.
func (*CasbinModelStatus) DeepCopyInto ¶
func (in *CasbinModelStatus) DeepCopyInto(out *CasbinModelStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type CasbinPolicy ¶
type CasbinPolicy struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec CasbinPolicySpec `json:"spec,omitempty"`
Status CasbinPolicyStatus `json:"status,omitempty"`
}
CasbinPolicy is the Schema for the Casbinpolicies API
func (*CasbinPolicy) DeepCopy ¶
func (in *CasbinPolicy) DeepCopy() *CasbinPolicy
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CasbinPolicy.
func (*CasbinPolicy) DeepCopyInto ¶
func (in *CasbinPolicy) DeepCopyInto(out *CasbinPolicy)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*CasbinPolicy) DeepCopyObject ¶
func (in *CasbinPolicy) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type CasbinPolicyList ¶
type CasbinPolicyList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []CasbinPolicy `json:"items"`
}
CasbinPolicyList contains a list of CasbinPolicy
func (*CasbinPolicyList) DeepCopy ¶
func (in *CasbinPolicyList) DeepCopy() *CasbinPolicyList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CasbinPolicyList.
func (*CasbinPolicyList) DeepCopyInto ¶
func (in *CasbinPolicyList) DeepCopyInto(out *CasbinPolicyList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*CasbinPolicyList) DeepCopyObject ¶
func (in *CasbinPolicyList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type CasbinPolicySpec ¶
type CasbinPolicySpec struct {
// PolicyItem is one line of policy
PolicyItem string `json:"policyItem"`
}
CasbinPolicySpec defines the desired state of CasbinPolicy
func (*CasbinPolicySpec) DeepCopy ¶
func (in *CasbinPolicySpec) DeepCopy() *CasbinPolicySpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CasbinPolicySpec.
func (*CasbinPolicySpec) DeepCopyInto ¶
func (in *CasbinPolicySpec) DeepCopyInto(out *CasbinPolicySpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type CasbinPolicyStatus ¶
type CasbinPolicyStatus struct {
}
CasbinPolicyStatus defines the observed state of CasbinPolicy
func (*CasbinPolicyStatus) DeepCopy ¶
func (in *CasbinPolicyStatus) DeepCopy() *CasbinPolicyStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CasbinPolicyStatus.
func (*CasbinPolicyStatus) DeepCopyInto ¶
func (in *CasbinPolicyStatus) DeepCopyInto(out *CasbinPolicyStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.