Documentation
¶
Overview ¶
This package has the automatically generated typed clients.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AuthV1Client ¶
type AuthV1Client struct {
// contains filtered or unexported fields
}
AuthV1Client is used to interact with features provided by the auth.casbin.org group.
func New ¶
func New(c rest.Interface) *AuthV1Client
New creates a new AuthV1Client for the given RESTClient.
func NewForConfig ¶
func NewForConfig(c *rest.Config) (*AuthV1Client, error)
NewForConfig creates a new AuthV1Client for the given config. NewForConfig is equivalent to NewForConfigAndClient(c, httpClient), where httpClient was generated with rest.HTTPClientFor(c).
func NewForConfigAndClient ¶
NewForConfigAndClient creates a new AuthV1Client for the given config and http client. Note the http client provided takes precedence over the configured transport values.
func NewForConfigOrDie ¶
func NewForConfigOrDie(c *rest.Config) *AuthV1Client
NewForConfigOrDie creates a new AuthV1Client for the given config and panics if there is an error in the config.
func (*AuthV1Client) CasbinModels ¶
func (c *AuthV1Client) CasbinModels(namespace string) CasbinModelInterface
func (*AuthV1Client) CasbinPolicies ¶
func (c *AuthV1Client) CasbinPolicies(namespace string) CasbinPolicyInterface
func (*AuthV1Client) RESTClient ¶
func (c *AuthV1Client) RESTClient() rest.Interface
RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.
type AuthV1Interface ¶
type AuthV1Interface interface {
RESTClient() rest.Interface
CasbinModelsGetter
CasbinPoliciesGetter
}
type CasbinModelExpansion ¶
type CasbinModelExpansion interface{}
type CasbinModelInterface ¶
type CasbinModelInterface interface {
Create(ctx context.Context, casbinModel *v1.CasbinModel, opts metav1.CreateOptions) (*v1.CasbinModel, error)
Update(ctx context.Context, casbinModel *v1.CasbinModel, opts metav1.UpdateOptions) (*v1.CasbinModel, error)
UpdateStatus(ctx context.Context, casbinModel *v1.CasbinModel, opts metav1.UpdateOptions) (*v1.CasbinModel, error)
Delete(ctx context.Context, name string, opts metav1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts metav1.DeleteOptions, listOpts metav1.ListOptions) error
Get(ctx context.Context, name string, opts metav1.GetOptions) (*v1.CasbinModel, error)
List(ctx context.Context, opts metav1.ListOptions) (*v1.CasbinModelList, error)
Watch(ctx context.Context, opts metav1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts metav1.PatchOptions, subresources ...string) (result *v1.CasbinModel, err error)
CasbinModelExpansion
}
CasbinModelInterface has methods to work with CasbinModel resources.
type CasbinModelsGetter ¶
type CasbinModelsGetter interface {
CasbinModels(namespace string) CasbinModelInterface
}
CasbinModelsGetter has a method to return a CasbinModelInterface. A group's client should implement this interface.
type CasbinPoliciesGetter ¶
type CasbinPoliciesGetter interface {
CasbinPolicies(namespace string) CasbinPolicyInterface
}
CasbinPoliciesGetter has a method to return a CasbinPolicyInterface. A group's client should implement this interface.
type CasbinPolicyExpansion ¶
type CasbinPolicyExpansion interface{}
type CasbinPolicyInterface ¶
type CasbinPolicyInterface interface {
Create(ctx context.Context, casbinPolicy *v1.CasbinPolicy, opts metav1.CreateOptions) (*v1.CasbinPolicy, error)
Update(ctx context.Context, casbinPolicy *v1.CasbinPolicy, opts metav1.UpdateOptions) (*v1.CasbinPolicy, error)
UpdateStatus(ctx context.Context, casbinPolicy *v1.CasbinPolicy, opts metav1.UpdateOptions) (*v1.CasbinPolicy, error)
Delete(ctx context.Context, name string, opts metav1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts metav1.DeleteOptions, listOpts metav1.ListOptions) error
Get(ctx context.Context, name string, opts metav1.GetOptions) (*v1.CasbinPolicy, error)
List(ctx context.Context, opts metav1.ListOptions) (*v1.CasbinPolicyList, error)
Watch(ctx context.Context, opts metav1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts metav1.PatchOptions, subresources ...string) (result *v1.CasbinPolicy, err error)
CasbinPolicyExpansion
}
CasbinPolicyInterface has methods to work with CasbinPolicy resources.