Documentation
¶
Overview ¶
Copyright 2022 The casbin Authors. All Rights Reserved.
Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
Copyright 2022 The casbin Authors. All Rights Reserved.
Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
Copyright 2022 The casbin Authors. All Rights Reserved.
Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
Copyright 2022 The casbin Authors. All Rights Reserved.
Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
Index ¶
- func Access(args ...interface{}) (interface{}, error)
- func AccessWithWildCard(args ...interface{}) (interface{}, error)
- func Contain(args ...interface{}) (interface{}, error)
- func HasPrefix(args ...interface{}) (interface{}, error)
- func IsNil(args ...interface{}) (interface{}, error)
- func Len(args ...interface{}) (interface{}, error)
- func MatchRegex(args ...interface{}) (interface{}, error)
- func ParseFloat(args ...interface{}) (interface{}, error)
- func ParseInt(args ...interface{}) (interface{}, error)
- func Split(args ...interface{}) (interface{}, error)
- func ToString(args ...interface{}) (interface{}, error)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AccessWithWildCard ¶
func AccessWithWildCard(args ...interface{}) (interface{}, error)
func MatchRegex ¶
func MatchRegex(args ...interface{}) (interface{}, error)
func ParseFloat ¶
func ParseFloat(args ...interface{}) (interface{}, error)
Types ¶
This section is empty.